From d6eb0be446410364a816dfca215dd2c356a80421 Mon Sep 17 00:00:00 2001
From: Aurelien Nephtali <aurelien@sitadelle.com>
Date: Wed, 31 Mar 2010 12:33:46 +0000
Subject: [PATCH 1/1] Fix infinite loop when accept4() is not usable

---
 src/network/httpd.c |   19 ++++++++++---------
 1 files changed, 10 insertions(+), 9 deletions(-)

diff --git a/src/network/httpd.c b/src/network/httpd.c
index 8dbdbf5..c76d5f1 100644
--- a/src/network/httpd.c
+++ b/src/network/httpd.c
@@ -2508,6 +2508,7 @@ static void* httpd_HostThread( void *data )
             httpd_client_t *cl;
             int i_state = -1;
             int fd = ufd[nfd].fd;
+            int newfd;
 
             assert (fd == host->fds[nfd]);
 
@@ -2516,22 +2517,22 @@ static void* httpd_HostThread( void *data )
 
             /* */
 #ifdef HAVE_ACCEPT4
-            fd = accept4 (fd, NULL, NULL, SOCK_CLOEXEC);
-            if (fd == -1 && errno == ENOSYS)
+            newfd = accept4 (fd, NULL, NULL, SOCK_CLOEXEC);
+            if (newfd == -1 && errno == ENOSYS)
 #endif
-            fd = accept (fd, NULL, NULL);
-            if (fd == -1)
+            newfd = accept (fd, NULL, NULL);
+            if (newfd == -1)
                 continue;
 
-            net_SetupSocket (fd);
+            net_SetupSocket (newfd);
             if( p_tls != NULL )
             {
-                switch( tls_ServerSessionHandshake( p_tls, fd ) )
+                switch( tls_ServerSessionHandshake( p_tls, newfd ) )
                 {
                     case -1:
                         msg_Err( host, "Rejecting TLS connection" );
-                        net_Close( fd );
-                        fd = -1;
+                        net_Close( newfd );
+                        newfd = -1;
                         p_tls = NULL;
                         break;
 
@@ -2550,7 +2551,7 @@ static void* httpd_HostThread( void *data )
 
             stats_UpdateInteger( host, p_total_counter, 1, NULL );
             stats_UpdateInteger( host, p_active_counter, 1, NULL );
-            cl = httpd_ClientNew( fd, p_tls, now );
+            cl = httpd_ClientNew( newfd, p_tls, now );
             p_tls = NULL;
             vlc_mutex_lock( &host->lock );
             TAB_APPEND( host->i_client, host->client, cl );
-- 
1.7.0

